#line 2 "bsdl_flex.c"

#line 4 "bsdl_flex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE urj_bsdl_restart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via urj_bsdl_restart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void urj_bsdl_restart (FILE *input_file ,yyscan_t yyscanner );
void urj_bsdl__switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE urj_bsdl__create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void urj_bsdl__delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void urj_bsdl__flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void urj_bsdl_push_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void urj_bsdl_pop_buffer_state (yyscan_t yyscanner );

static void urj_bsdl_ensure_buffer_stack (yyscan_t yyscanner );
static void urj_bsdl__load_buffer_state (yyscan_t yyscanner );
static void urj_bsdl__init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER urj_bsdl__flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE urj_bsdl__scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE urj_bsdl__scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE urj_bsdl__scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *urj_bsdl_alloc (yy_size_t ,yyscan_t yyscanner );
void *urj_bsdl_realloc (void *,yy_size_t ,yyscan_t yyscanner );
void urj_bsdl_free (void * ,yyscan_t yyscanner );

#define yy_new_buffer urj_bsdl__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        urj_bsdl_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            urj_bsdl__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        urj_bsdl_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            urj_bsdl__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 116
#define YY_END_OF_BUFFER 117
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[880] =
    {   0,
      107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
      107,  107,  117,  115,  116,  107,  116,   99,  116,  116,
      101,  116,  102,  116,  106,  116,  100,  116,  116,  109,
      110,  112,  113,  116,  110,  113,  116,  105,  116,  110,
      111,  116,  110,  111,  116,  110,  111,  116,  111,  116,
      111,  116,  111,  116,  111,  116,  111,  116,  111,  116,
      111,  116,  109,  111,  116,  103,  116,  104,  116,  110,
      111,  116,  110,  111,  116,  111,  116,  111,  116,  111,
      116,  111,  116,  111,  116,   93,  111,  116,  110,  111,
      116,  110,  111,  116,  110,  111,  116,  110,  111,  116,

      111,  116,  111,  116,  111,  116,  111,  116,  111,  116,
      111,  116,  110,  111,  116,   63,  116,   54,  116,   56,
      116,   57,  116,  116,   55,  116,  116,   62,  116,  110,
      111,  116,  110,  111,  116,  110,  111,  116,  111,  116,
      111,  116,  111,  116,  111,  116,  111,  116,  111,  116,
      111,  116,  111,  116,  111,  116,  111,  116,   60,  116,
      107,  108,  109,  110,  112,  113,  110,  113,  110,  109,
      110,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  109,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  110,  111,

      111,  111,  111,  111,  111,  111,  111,  111,  111,   59,
       58,   61,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  108,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,   52,  111,  111,  111,  111,
      111,   51,  111,   50,  111,  111,   53,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,

      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,   48,  111,  111,  111,  111,
      111,  111,  111,  111,  111,   49,  111,  114,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,   90,  111,
       88,  111,  111,   82,  111,  111,  111,  111,  111,   96,
      111,   97,  111,   94,  111,   95,  111,  111,  111,   72,
      111,  111,  111,   74,  111,  111,  111,  111,  111,  111,
      111,  111,   42,  111,  111,  111,  111,  111,  111,  111,

      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,   98,  111,  111,  111,  111,   70,  111,  111,   73,
      111,   75,  111,   76,  111,  111,  111,   79,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,   46,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,    2,  111,  111,  111,  111,  111,  111,   86,  111,
      111,  111,   83,  111,   84,  111,  111,  111,   77,  111,

       78,  111,  111,  111,  111,  111,  111,  111,  111,   44,
       77,  111,  111,  111,  111,  111,  111,  111,  111,  111,
        1,  111,  111,  111,  111,  111,  111,  111,  111,   39,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,   85,  111,   87,  111,  111,   71,  111,
      111,   80,  111,   91,  111,  111,  111,  111,  111,   67,
      111,  111,  111,   43,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
       81,  111,   92,  111,  111,  111,  111,  111,  111,   47,

      111,  111,  111,  111,  111,  111,  111,  111,   65,  111,
      111,  111,  111,  111,  111,  111,  111,  111,   31,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,   45,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,    5,
      111,  111,  111,  111,  111,  111,  111,   32,  111,   66,
      111,   68,  111,   40,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,   34,  111,
      111,  111,  111,  111,  111,  111,  111,  111,    6,  111,

      111,  111,   89,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,   64,  111,  111,  111,  111,
      111,  111,   27,  111,   28,  111,  111,    8,  111,  111,
      111,   41,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,    4,  111,  111,  111,  111,    7,
      111,    9,  111,  111,   17,  111,  111,  111,  111,   19,
      111,  111,  111,  111,  111,  111,  111,  111,   26,  111,
      111,   38,  111,  111,  111,  111,  111,  111,  111,   16,

      111,   23,  111,   24,  111,   25,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
       35,  111,  111,   69,  111,   29,  111,    3,  111,  111,
       18,  111,  111,  111,  111,  111,   14,  111,  111,  111,
      111,  111,   37,  111,  111,  111,   20,  111,  111,  111,
      111,  111,   10,  111,   11,  111,  111,   33,  111,  111,
      111,   21,  111,  111,   12,  111,   13,  111,   15,  111,
       36,  111,  111,  111,  111,   22,  111,   30,  111
    } ;

static yyconst flex_int16_t yy_accept[710] =
    {   0,
        1,    2,    3,    4,    5,    6,    7,    8,    9,   10,
       11,   12,   13,   14,   16,   18,   20,   21,   23,   25,
       27,   29,   30,   35,   38,   40,   43,   46,   49,   51,
       53,   55,   57,   59,   61,   63,   66,   68,   70,   73,
       76,   78,   80,   82,   84,   86,   89,   92,   95,   98,
      101,  103,  105,  107,  109,  111,  113,  116,  118,  120,
      122,  124,  125,  127,  128,  130,  133,  136,  139,  141,
      143,  145,  147,  149,  151,  153,  155,  157,  159,  161,
      162,  163,  163,  167,  169,  170,  171,  173,  174,  175,
      176,  177,  178,  179,  180,  181,  182,  183,  184,  185,

      187,  188,  189,  190,  191,  192,  193,  194,  195,  196,
      197,  198,  199,  201,  202,  203,  204,  205,  206,  207,
      208,  209,  210,  211,  212,  213,  214,  215,  216,  217,
      218,  219,  220,  221,  222,  223,  224,  225,  226,  227,
      228,  229,  230,  230,  231,  232,  233,  234,  235,  236,
      237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
      247,  248,  249,  250,  251,  252,  253,  254,  255,  256,
      257,  258,  259,  260,  261,  262,  263,  264,  265,  266,
      268,  269,  270,  271,  272,  274,  276,  277,  279,  280,
      281,  282,  283,  284,  285,  286,  287,  287,  288,  289,

      290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
      300,  301,  302,  303,  304,  305,  306,  307,  308,  309,
      310,  311,  312,  313,  314,  315,  316,  317,  318,  319,
      320,  321,  322,  323,  324,  325,  326,  328,  329,  330,
      331,  332,  333,  334,  335,  336,  338,  338,  339,  340,
      341,  342,  343,  344,  345,  346,  347,  348,  349,  350,
      351,  352,  353,  354,  355,  356,  357,  358,  359,  361,
      363,  364,  366,  367,  368,  369,  370,  372,  374,  376,
      378,  379,  380,  382,  383,  384,  386,  387,  388,  389,
      390,  391,  392,  393,  395,  396,  397,  398,  399,  400,

      401,  402,  403,  404,  405,  406,  407,  408,  409,  410,
      411,  412,  413,  414,  415,  416,  417,  418,  419,  420,
      421,  422,  423,  424,  425,  426,  427,  428,  429,  430,
      431,  432,  434,  435,  436,  437,  439,  440,  442,  444,
      446,  447,  448,  450,  451,  452,  453,  454,  455,  456,
      457,  458,  459,  461,  462,  463,  464,  465,  466,  467,
      468,  469,  470,  471,  472,  473,  474,  475,  476,  477,
      478,  479,  480,  481,  482,  484,  485,  486,  487,  488,
      489,  491,  492,  493,  495,  497,  498,  499,  501,  503,
      504,  505,  506,  507,  508,  509,  510,  513,  514,  515,

      516,  517,  518,  519,  520,  521,  523,  524,  525,  526,
      527,  528,  529,  530,  532,  533,  534,  535,  536,  537,
      538,  539,  540,  541,  542,  543,  544,  546,  548,  549,
      551,  552,  554,  556,  557,  558,  559,  560,  562,  563,
      564,  566,  567,  568,  569,  570,  571,  572,  573,  574,
      575,  576,  577,  578,  579,  580,  581,  582,  583,  584,
      585,  586,  587,  588,  589,  590,  591,  593,  595,  596,
      597,  598,  599,  600,  602,  603,  604,  605,  606,  607,
      608,  609,  611,  612,  613,  614,  615,  616,  617,  618,
      619,  621,  622,  623,  624,  625,  626,  627,  628,  629,

      630,  631,  632,  633,  634,  635,  637,  638,  639,  640,
      641,  642,  643,  644,  645,  646,  647,  648,  649,  650,
      651,  652,  653,  654,  655,  656,  657,  658,  659,  660,
      662,  663,  664,  665,  666,  667,  668,  670,  672,  674,
      676,  677,  678,  679,  680,  681,  682,  683,  684,  685,
      686,  687,  688,  689,  691,  692,  693,  694,  695,  696,
      697,  698,  699,  701,  702,  703,  705,  706,  707,  708,
      709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
      719,  720,  721,  722,  723,  724,  725,  726,  728,  729,
      730,  731,  732,  733,  735,  737,  738,  740,  741,  742,

      744,  745,  746,  747,  748,  749,  750,  751,  752,  753,
      754,  755,  756,  757,  758,  759,  760,  761,  762,  763,
      764,  765,  767,  768,  769,  770,  772,  774,  775,  777,
      778,  779,  780,  782,  783,  784,  785,  786,  787,  788,
      789,  791,  792,  794,  795,  796,  797,  798,  799,  800,
      802,  804,  806,  808,  809,  810,  811,  812,  813,  814,
      815,  816,  817,  818,  819,  820,  821,  823,  824,  826,
      828,  830,  831,  833,  834,  835,  836,  837,  839,  840,
      841,  842,  843,  845,  846,  847,  849,  850,  851,  852,
      853,  855,  857,  858,  860,  861,  862,  864,  865,  867,

      869,  871,  873,  874,  875,  876,  878,  880,  880
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    6,    1,    5,    5,    7,
        8,    9,   10,   11,   12,   13,    1,   14,   15,   16,
       17,   18,   19,   20,   20,   20,   21,   22,    5,   23,
       24,   25,   26,    1,   27,   28,   29,   30,   31,   32,
       33,   34,   35,   36,   37,   38,   39,   40,   41,   42,
       36,   43,   44,   45,   46,   47,   48,   49,   50,   51,
       52,    1,   53,    1,   54,    1,   55,   56,   57,   58,

       59,   60,   61,   62,   63,   36,   64,   65,   66,   67,
       68,   69,   36,   70,   71,   72,   73,   74,   75,   76,
       77,   78,    1,    1,    1,   79,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[80] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    1,    1,    1,    1,    1,    3,    3,    3,    3,
        3,    3,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    1,    1,    4,    3,    3,    3,    3,    3,    3,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    1
    } ;

static yyconst flex_uint16_t yy_base[712] =
    {   0,
        0,    0,    0,    0,   52,    0,  103,    0,   55,  100,
      173,    0,  691, 1591,  688, 1591, 1591, 1591, 1591, 1591,
     1591,  624,  240,   77, 1591,  303,  350,   45,    0,  207,
      108,   51,   50,   70,   73,   91, 1591, 1591,   89,  110,
      236,  105,  167,  147,  127,    0,  234,  241,  242,  236,
      159,  285,  341,  282,  236,  136,  166, 1591, 1591, 1591,
      574,  559, 1591,  541,  545,  304,  347,  345,  384,  165,
      398,  351,  395,  395,  404,  405,  399,  176, 1591,  511,
        0,  463,    0,  278,    0,  324,  194,    0,  241,  405,
      370,  282,  390,  339,  400,  401,  416,  406,  438,  471,

      443,  446,  449,  450,  459,  452,  453,  461,  473,  456,
      461,  477,  465,  462,  475,  480,  496,  479,  477,  485,
      496,  501, 1591, 1591, 1591,  492,  513,  508,  503,  513,
      505,  501,  512,  509,  511,  533,  536,  531,  520,  533,
      526,    0,  592,  547,  549,  550,  554,  553,  457,  555,
      451,  561,  439,  437,  557,  568,  575,  571,  571,  588,
      586,  589,  587,  592,  596,  594,  608,  598,  603,  608,
      606,  604,  610,  608,  621,  610,  610,  615,  627,    0,
      613,  621,  617,  623,    0,    0,  635,    0,  636,  633,
      635,  640,  635,  644,  641,  642,  703,  658,  666,  655,

      667,  662,  708,  691,  667,  668,  441,  684,  700,  699,
      708,  703,  702,  705,  699,  706,  705,   84,   87,  723,
      712,  717,  731,  718,  716,  740,  736,  741,  749,  749,
      756,  747,  741,  398,  761,  758,    0,  754,  755,  754,
      760,  773,  759,  768,  764,    0,  819,  827,  798,  792,
      790,  822,  819,  806,  825,  818,  817,  824,  825,  824,
      829,  835,  836,  840,  824,  135,  841,  832,    0,    0,
      833,    0,  835,  833,  834,  839,    0,    0,    0,    0,
      859,  847,    0,  866,  859,    0,  874,  864,  879,  866,
      881,  874,  383,    0,  875,  878,  886,  879,  893,  886,

      884,  879,  891,  888,  900,  889,  903,  904,  898,  348,
      910,  900,  920,  912,  909,  907,  919,  923,  922,  923,
      937,  941,  942,  929,  942,  383,  381,  947,  946,  940,
      954,    0,  951,  171,  941,    0,  343,    0,  342,    0,
      955,  945,    0,  956,  958,  952,  964,  962,  976,  976,
      976,  977,    0,  967,  988,  985,  968,  980,  982,  979,
      982,  983,  994,  992,  998, 1006, 1006,  992, 1007,  338,
     1012, 1000, 1003, 1012,  333, 1010,  362,  341, 1014, 1011,
     1013, 1022,  297,    0,    0, 1012, 1028,    0,    0, 1033,
     1028, 1025,  296, 1032, 1039, 1038,    0, 1033, 1039, 1032,

     1039, 1041,  295, 1057, 1043,    0, 1059, 1058, 1055, 1060,
     1059, 1066, 1071,    0, 1071, 1079, 1077, 1067, 1067,  294,
     1072,  292,  290,  288,  286,  283,    0,    0, 1076,  282,
     1089,  251,    0, 1080, 1089, 1081, 1077,    0, 1103, 1101,
        0, 1102, 1094, 1103, 1103,  236, 1106, 1101, 1105,  234,
     1106, 1112,  232, 1124, 1123, 1126, 1122, 1116, 1121, 1119,
     1139,  249,  234, 1154, 1128, 1134,    0,    0, 1132, 1147,
     1149, 1143, 1150,    0, 1157, 1168, 1169,  195, 1174, 1169,
     1152,    0, 1150, 1168, 1174, 1166, 1174, 1180, 1172, 1176,
        0, 1180, 1182, 1197,  180,  213, 1191, 1190, 1194, 1190,

     1207, 1209, 1206, 1203, 1211,    0, 1197, 1219, 1220, 1213,
     1218, 1213, 1217, 1215,  172, 1216, 1234,  171, 1214,  170,
     1238, 1224, 1220, 1232, 1240, 1247,  174,  191, 1240,    0,
     1253, 1243, 1246, 1251, 1242, 1254,    0,    0,    0,    0,
     1263, 1263, 1273, 1262, 1260, 1304, 1276, 1269, 1307, 1269,
     1289, 1267, 1292,    0,  130, 1276, 1294,  148,  141,  176,
     1298, 1299,    0, 1300, 1304,    0, 1304, 1307, 1310, 1311,
     1325, 1329, 1336, 1329, 1322, 1339, 1333, 1335, 1337, 1353,
     1341, 1355, 1346, 1356, 1345, 1344, 1359,    0, 1357, 1364,
     1355,  118,  105,    0,    0, 1363,    0, 1356, 1359,    0,

     1370, 1361, 1363, 1368, 1369, 1371, 1374, 1392, 1381, 1395,
     1394, 1402, 1403, 1410, 1391, 1401, 1411, 1412, 1409, 1405,
     1422,    0, 1407,   71,   99,    0,    0, 1408,    0, 1423,
     1424, 1415,    0, 1415, 1429, 1418, 1430, 1426, 1423, 1433,
        0, 1431,    0, 1431, 1446, 1440, 1436, 1443, 1447,    0,
        0,    0,    0, 1459, 1450, 1452, 1457, 1452, 1471, 1470,
     1458, 1475, 1480, 1479, 1479, 1469,    0,   53,    0,    0,
        0, 1471,    0, 1475, 1490, 1476, 1483,    0, 1490, 1495,
     1484, 1500,    0, 1505, 1492,    0, 1492, 1500, 1512, 1513,
        0,    0, 1516,    0, 1510, 1515,    0, 1522,    0,    0,

        0,    0, 1513, 1524, 1513,    0,    0, 1591, 1582, 1586,
      101
    } ;

static yyconst flex_int16_t yy_def[712] =
    {   0,
      708,    1,    1,    1,    1,    5,    1,    7,    1,    1,
        7,   11,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,   23,  708,  709,  709,   27,  709,  709,
      709,  709,  709,  709,  709,  709,  708,  708,   27,   27,
      709,  709,  709,  709,  709,  709,   27,   27,   27,   27,
      709,  709,  709,  709,  709,  709,   27,  708,  708,  708,
      708,  708,  708,  708,  708,   27,   27,   27,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  708,  708,
      710,  708,   23,   23,  711,  708,   27,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,   27,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  708,  708,  708,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  710,  708,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  708,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  708,  708,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  709,

      709,  709,  709,  709,  709,  709,  709,    0,  708,  708,
      708
    } ;

static yyconst flex_uint16_t yy_nxt[1671] =
    {   0,
       14,   15,   16,   17,   17,   17,   18,   19,   20,   17,
       21,   22,   17,   23,   23,   24,   24,   24,   24,   24,
       24,   25,   17,   17,   17,   17,   26,   27,   28,   26,
       26,   26,   29,   29,   30,   29,   29,   29,   29,   29,
       29,   31,   32,   33,   34,   35,   29,   29,   36,   29,
       29,   37,   38,   17,   26,   27,   28,   26,   26,   26,
       29,   29,   30,   29,   29,   29,   29,   29,   31,   32,
       33,   34,   35,   29,   29,   36,   29,   29,   17,   39,
       40,   96,   57,   40,  651,   90,   41,  652,   42,   41,
       84,   84,   43,   44,   97,   43,   98,  277,  278,   45,

      279,  280,   46,   85,  100,  100,  685,   39,   40,   96,
       57,   40,   90,  653,   41,   42,   99,   41,  625,   43,
       44,   97,   43,  101,   98,  708,   45,   57,   40,   46,
       47,   48,   49,   50,   41,  105,   51,   52,  624,  100,
       43,   94,   95,   99,   53,   54,   55,  102,   56,  326,
      103,  101,  708,  327,  593,   57,   40,  109,   47,   48,
       49,   50,   41,  105,   51,   52,  100,   43,  592,   94,
       95,   53,   54,   55,  102,   56,   58,  103,   59,  121,
       94,   95,   60,  589,   61,  109,  384,  385,  558,  559,
      594,  595,  108,  115,  106,   62,   63,   64,   65,   66,

      122,   67,  141,   68,  560,  131,  121,   69,   94,   95,
       70,   71,  107,   72,   73,   74,   75,   76,   77,  108,
       78,  115,  106,  551,  549,  546,  528,   66,  122,   67,
      141,   68,  131,  527,   88,   69,   91,   70,   71,  107,
       72,   73,   74,   75,   76,   77,   92,   78,  512,  496,
       93,   79,   82,   83,   83,   84,   84,   84,   84,   84,
       84,   88,  120,  495,   91,   91,   85,   85,   85,   85,
       85,   85,  113,   92,  110,  104,   88,   93,  112,   93,
       97,   90,   88,  111,  114,  486,  144,  483,   86,  479,
      120,   84,   84,   91,   85,   85,   85,   85,   85,   85,

      113,  110,  104,   88,  465,  112,   93,   97,   90,   88,
      111,  114,   96,  144,  116,   86,   87,   87,   87,   87,
       87,   87,   87,   87,  117,  148,  708,  119,   93,   87,
       87,   87,   87,   87,   87,  444,  465,   86,   86,  464,
       96,  463,  116,  462,   88,  461,  126,  459,  444,  435,
      429,  117,  148,  708,  119,   93,  424,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   88,   86,  126,   94,   95,   87,   87,   87,   87,
       87,   87,  423,  118,  112,   88,  421,   90,  150,  127,
       89,  416,  134,  128,  135,  361,  387,  378,  147,   86,

      377,  361,   94,   95,   87,   87,   87,   87,   87,   87,
      118,  112,   88,  116,   90,  150,  127,   89,  149,  134,
      128,  135,  129,  130,  132,  137,  147,   93,   94,   95,
      120,   98,  133,  152,  138,  139,  345,  136,  140,  151,
      119,  116,  121,  145,  146,  153,  149,  154,   97,  129,
      130,  295,  132,  137,   93,  266,   94,   95,  120,   98,
      133,  152,  138,  139,  136,  140,  151,  119,  155,  121,
      145,  146,  156,  153,  154,   97,  143,  143,  143,  143,
      143,  143,  143,  143,  100,  100,  157,  145,  158,  161,
      208,  159,  207,  148,  160,  162,  155,  163,  164,  165,

      156,  166,  167,  168,  205,   88,  170,  171,  172,  174,
      203,  169,   80,  157,  145,  158,  175,  161,  159,  100,
      148,  160,  162,  176,  163,  164,  177,  165,  166,  167,
      178,  168,   88,  170,  179,  171,  172,  174,  169,  148,
      173,  180,  181,  175,  182,  184,  100,  183,  125,  185,
      176,  186,  170,  187,  177,  188,  148,  173,  178,  193,
      196,  179,  194,  189,  191,  124,  148,  173,  152,  180,
      181,  182,  184,  190,  195,  183,  185,  192,  186,  170,
      187,  123,  188,  148,  173,   81,  198,  193,  196,  194,
      199,  189,  191,  200,  201,  206,  152,  202,  204,  209,

      190,  195,  210,  211,  192,  143,  143,  143,  143,  143,
      143,  143,  143,  198,  200,  212,  213,  199,  214,  216,
      200,  201,  197,  206,  202,  204,  209,  215,  217,  218,
      210,  211,  219,  220,  221,   81,  222,  223,  224,  225,
      227,  200,  212,  213,  226,  228,  214,  216,  229,  232,
      197,  230,  231,  233,  215,  217,  218,  234,  235,  219,
      220,  236,  221,  222,  237,  223,  224,  225,  227,  238,
      242,  226,  228,  239,  240,  241,  229,  232,  230,  231,
      243,  233,  244,  245,  234,  235,  246,  249,  236,   80,
      708,  237,  708,  708,  708,  708,  253,  238,  242,  252,

      239,  240,  241,  250,  254,  264,  251,  243,  708,  244,
      245,  265,  247,  246,  247,  249,  248,  248,  248,  248,
      248,  248,  248,  248,  253,  263,  252,  267,  268,  274,
      250,  254,  264,  251,  255,  256,  257,  258,  265,  259,
      708,  269,  260,  708,  270,  271,  272,  273,  275,  261,
      276,  262,  281,  263,  267,  282,  268,  274,  283,  284,
      708,  285,  255,  256,  257,  258,  286,  259,  269,  287,
      260,  270,  271,  272,  273,  275,  261,  276,  262,  288,
      281,  289,  282,  290,  292,  283,  291,  284,  285,  293,
      294,  296,  297,  286,  298,  299,  300,  287,  301,  302,

      708,  303,  304,  708,  305,  708,  288,  708,  289,  708,
      708,  290,  292,  291,  708,  708,  293,  294,  708,  296,
      297,  298,  299,  300,  306,  301,  307,  302,  303,  308,
      304,  305,  248,  248,  248,  248,  248,  248,  248,  248,
      248,  248,  248,  248,  248,  248,  248,  248,  309,  310,
      708,  311,  306,  312,  307,  313,  308,  314,  315,  316,
      708,  318,  317,  319,  323,  321,  324,  708,  325,  328,
      708,  320,  329,  330,  331,  332,  309,  310,  311,  322,
      333,  312,  313,  334,  314,  335,  315,  316,  318,  317,
      336,  319,  323,  321,  324,  325,  337,  328,  320,  329,

      330,  331,  332,  338,  339,  341,  322,  333,  340,  342,
      334,  343,  348,  335,  344,  346,  347,  336,  349,  350,
      351,  708,  352,  353,  337,  354,  708,  355,  356,  358,
      338,  357,  339,  341,  359,  340,  342,  360,  362,  343,
      348,  344,  346,  347,  363,  349,  364,  350,  351,  352,
      353,  365,  366,  354,  355,  367,  356,  358,  357,  368,
      369,  370,  359,  371,  360,  372,  362,  373,  374,  708,
      375,  363,  376,  379,  364,  380,  708,  381,  365,  366,
      382,  383,  367,  386,  388,  390,  368,  369,  370,  389,
      371,  393,  391,  372,  394,  373,  374,  375,  392,  395,

      376,  379,  396,  380,  381,  397,  398,  399,  382,  383,
      386,  400,  388,  390,  401,  402,  389,  403,  393,  404,
      391,  405,  394,  406,  407,  392,  395,  408,  409,  411,
      396,  410,  412,  397,  398,  399,  413,  415,  400,  414,
      417,  426,  401,  402,  403,  418,  404,  419,  405,  420,
      406,  407,  422,  425,  408,  427,  409,  411,  410,  428,
      412,  430,  431,  432,  413,  415,  414,  433,  417,  426,
      434,  436,  418,  437,  419,  438,  420,  439,  440,  422,
      425,  441,  427,  442,  443,  445,  428,  446,  430,  447,
      431,  432,  448,  452,  433,  449,  450,  434,  436,  451,

      453,  437,  438,  454,  439,  440,  455,  456,  441,  457,
      442,  443,  458,  445,  446,  460,  466,  447,  467,  469,
      448,  452,  449,  450,  468,  470,  451,  471,  453,  472,
      473,  454,  474,  478,  455,  456,  457,  475,  480,  458,
      476,  481,  460,  466,  482,  477,  467,  469,  484,  485,
      487,  468,  470,  488,  471,  489,  490,  472,  473,  491,
      474,  478,  492,  493,  475,  494,  480,  476,  481,  708,
      502,  482,  477,  503,  504,  484,  485,  505,  487,  506,
      508,  488,  497,  489,  490,  507,  491,  509,  498,  492,
      493,  515,  499,  494,  500,  516,  501,  502,  510,  511,

      503,  504,  513,  514,  518,  505,  517,  506,  508,  519,
      497,  520,  507,  521,  524,  509,  498,  522,  515,  499,
      523,  500,  516,  501,  525,  526,  510,  511,  529,  530,
      513,  514,  518,  517,  531,  532,  519,  533,  520,  534,
      537,  521,  524,  535,  522,  536,  538,  523,  539,  540,
      542,  525,  541,  526,  543,  529,  530,  544,  545,  547,
      548,  531,  532,  550,  552,  533,  553,  534,  537,  554,
      535,  555,  536,  538,  556,  557,  539,  540,  542,  541,
      561,  543,  562,  565,  544,  545,  547,  563,  548,  564,
      550,  566,  552,  553,  567,  568,  554,  569,  555,  570,

      708,  571,  556,  557,  572,  708,  579,  561,  580,  708,
      562,  565,  585,  587,  563,  590,  564,  708,  566,  586,
      708,  567,  588,  568,  591,  569,  596,  570,  571,  597,
      598,  572,  573,  574,  579,  580,  575,  581,  599,  585,
      587,  576,  590,  582,  577,  578,  600,  586,  583,  584,
      588,  601,  591,  602,  596,  603,  604,  597,  598,  605,
      573,  574,  606,  607,  575,  581,  599,  608,  576,  609,
      582,  577,  578,  600,  610,  583,  584,  611,  601,  612,
      602,  613,  603,  614,  604,  615,  617,  605,  616,  618,
      606,  607,  619,  620,  608,  621,  622,  609,  623,  626,

      627,  610,  628,  629,  611,  630,  612,  631,  632,  613,
      614,  633,  634,  615,  617,  616,  618,  635,  636,  619,
      637,  620,  621,  638,  622,  623,  626,  627,  639,  628,
      640,  629,  630,  641,  631,  632,  642,  645,  633,  634,
      643,  644,  646,  647,  635,  648,  636,  637,  649,  708,
      650,  638,  654,  655,  656,  659,  639,  657,  640,  658,
      660,  641,  661,  666,  642,  645,  662,  643,  644,  663,
      646,  647,  648,  664,  665,  667,  649,  650,  668,  654,
      669,  655,  656,  659,  657,  670,  658,  660,  671,  672,
      661,  666,  673,  662,  674,  675,  663,  676,  677,  678,

      664,  665,  679,  667,  680,  668,  681,  669,  682,  683,
      708,  684,  670,  686,  687,  671,  688,  672,  689,  673,
      690,  674,  675,  691,  676,  692,  677,  678,  693,  679,
      694,  695,  680,  696,  681,  697,  682,  683,  684,  698,
      686,  687,  699,  700,  688,  689,  701,  690,  702,  703,
      704,  691,  705,  692,  706,  693,  707,  708,  694,  695,
      696,  708,  697,  708,  708,  708,  698,  708,  708,  708,
      699,  700,  708,  708,  701,  702,  708,  703,  704,  705,
      708,  708,  706,  707,   88,   88,  142,  708,  142,  142,
       13,  708,  708,  708,  708,  708,  708,  708,  708,  708,

      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708
    } ;

static yyconst flex_int16_t yy_chk[1671] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    5,
        5,   32,    9,    9,  624,   28,    5,  624,    5,    9,
       24,   24,    5,    5,   33,    9,   34,  218,  218,    5,

      219,  219,    5,  711,   36,   36,  668,    5,    5,   32,
        9,    9,   28,  625,    5,    5,   35,    9,  593,    5,
        5,   33,    9,   39,   34,   24,    5,   10,   10,    5,
        7,    7,    7,    7,   10,   42,    7,    7,  592,   36,
       10,   31,   31,   35,    7,    7,    7,   40,    7,  266,
       40,   39,   24,  266,  559,   10,   10,   45,    7,    7,
        7,    7,   10,   42,    7,    7,   36,   10,  558,   31,
       31,    7,    7,    7,   40,    7,   11,   40,   11,   56,
       44,   44,   11,  555,   11,   45,  334,  334,  527,  527,
      560,  560,   44,   51,   43,   11,   11,   11,   11,   11,

       57,   11,   78,   11,  528,   70,   56,   11,   44,   44,
       11,   11,   43,   11,   11,   11,   11,   11,   11,   44,
       11,   51,   43,  520,  518,  515,  496,   11,   57,   11,
       78,   11,   70,  495,   87,   11,   30,   11,   11,   43,
       11,   11,   11,   11,   11,   11,   30,   11,  478,  463,
       30,   11,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   87,   55,  462,   30,   41,   23,   23,   23,   23,
       23,   23,   49,   30,   47,   41,   50,   30,   48,   41,
       55,   48,   49,   47,   50,  453,   89,  450,   23,  446,
       55,   84,   84,   41,   23,   23,   23,   23,   23,   23,

       49,   47,   41,   50,  432,   48,   41,   55,   48,   49,
       47,   50,   54,   89,   52,   23,   26,   26,   26,   26,
       26,   26,   26,   26,   52,   92,   84,   54,   52,   26,
       26,   26,   26,   26,   26,  430,  426,   86,   86,  425,
       54,  424,   52,  423,   66,  422,   66,  420,  403,  393,
      383,   52,   92,   84,   54,   52,  378,   26,   26,   26,
       26,   26,   26,   27,   27,   27,   27,   27,   27,   27,
       27,   66,   86,   66,   53,   53,   27,   27,   27,   27,
       27,   27,  377,   53,   67,   68,  375,   67,   94,   67,
       27,  370,   72,   68,   72,  339,  337,  327,   91,   86,

      326,  310,   53,   53,   27,   27,   27,   27,   27,   27,
       53,   67,   68,   69,   67,   94,   67,   27,   93,   72,
       68,   72,   69,   69,   71,   74,   91,   69,   73,   73,
       75,   76,   71,   96,   75,   76,  293,   73,   77,   95,
       74,   69,   77,   90,   90,   97,   93,   98,   75,   69,
       69,  234,   71,   74,   69,  207,   73,   73,   75,   76,
       71,   96,   75,   76,   73,   77,   95,   74,   99,   77,
       90,   90,  101,   97,   98,   75,   82,   82,   82,   82,
       82,   82,   82,   82,  100,  100,  102,  103,  103,  105,
      154,  104,  153,  104,  104,  106,   99,  107,  108,  109,

      101,  110,  111,  112,  151,  113,  114,  115,  116,  118,
      149,  113,   80,  102,  103,  103,  119,  105,  104,  100,
      104,  104,  106,  120,  107,  108,  121,  109,  110,  111,
      122,  112,  113,  114,  126,  115,  116,  118,  113,  117,
      117,  127,  128,  119,  129,  131,  100,  130,   65,  132,
      120,  133,  128,  134,  121,  135,  130,  130,  122,  138,
      141,  126,  139,  136,  137,   64,  117,  117,  137,  127,
      128,  129,  131,  136,  140,  130,  132,  137,  133,  128,
      134,   62,  135,  130,  130,   61,  144,  138,  141,  139,
      145,  136,  137,  146,  147,  152,  137,  148,  150,  155,

      136,  140,  156,  157,  137,  143,  143,  143,  143,  143,
      143,  143,  143,  144,  158,  158,  159,  145,  160,  162,
      146,  147,  143,  152,  148,  150,  155,  161,  163,  164,
      156,  157,  165,  166,  167,   22,  168,  169,  170,  171,
      173,  158,  158,  159,  172,  174,  160,  162,  175,  178,
      143,  176,  177,  179,  161,  163,  164,  181,  182,  165,
      166,  183,  167,  168,  184,  169,  170,  171,  173,  187,
      192,  172,  174,  189,  190,  191,  175,  178,  176,  177,
      193,  179,  194,  195,  181,  182,  196,  198,  183,   15,
       13,  184,    0,    0,    0,    0,  201,  187,  192,  200,

      189,  190,  191,  199,  202,  205,  199,  193,    0,  194,
      195,  206,  197,  196,  197,  198,  197,  197,  197,  197,
      197,  197,  197,  197,  201,  204,  200,  208,  209,  215,
      199,  202,  205,  199,  203,  203,  203,  203,  206,  203,
        0,  210,  203,    0,  211,  212,  213,  214,  216,  203,
      217,  203,  220,  204,  208,  221,  209,  215,  222,  223,
        0,  224,  203,  203,  203,  203,  225,  203,  210,  226,
      203,  211,  212,  213,  214,  216,  203,  217,  203,  227,
      220,  228,  221,  229,  231,  222,  230,  223,  224,  232,
      233,  235,  236,  225,  238,  239,  240,  226,  241,  242,

        0,  243,  244,    0,  245,    0,  227,    0,  228,    0,
        0,  229,  231,  230,    0,    0,  232,  233,    0,  235,
      236,  238,  239,  240,  249,  241,  250,  242,  243,  251,
      244,  245,  247,  247,  247,  247,  247,  247,  247,  247,
      248,  248,  248,  248,  248,  248,  248,  248,  252,  253,
        0,  254,  249,  255,  250,  256,  251,  257,  258,  259,
        0,  260,  259,  261,  263,  262,  264,    0,  265,  267,
        0,  261,  268,  271,  273,  274,  252,  253,  254,  262,
      275,  255,  256,  276,  257,  281,  258,  259,  260,  259,
      282,  261,  263,  262,  264,  265,  284,  267,  261,  268,

      271,  273,  274,  285,  287,  289,  262,  275,  288,  290,
      276,  291,  297,  281,  292,  295,  296,  282,  298,  299,
      300,    0,  301,  302,  284,  303,    0,  304,  305,  307,
      285,  306,  287,  289,  308,  288,  290,  309,  311,  291,
      297,  292,  295,  296,  312,  298,  313,  299,  300,  301,
      302,  314,  315,  303,  304,  316,  305,  307,  306,  317,
      318,  319,  308,  320,  309,  321,  311,  322,  323,    0,
      324,  312,  325,  328,  313,  329,    0,  330,  314,  315,
      331,  333,  316,  335,  341,  344,  317,  318,  319,  342,
      320,  346,  345,  321,  347,  322,  323,  324,  345,  348,

      325,  328,  349,  329,  330,  350,  351,  352,  331,  333,
      335,  354,  341,  344,  355,  356,  342,  357,  346,  358,
      345,  359,  347,  360,  361,  345,  348,  362,  363,  365,
      349,  364,  366,  350,  351,  352,  367,  369,  354,  368,
      371,  380,  355,  356,  357,  372,  358,  373,  359,  374,
      360,  361,  376,  379,  362,  381,  363,  365,  364,  382,
      366,  386,  387,  390,  367,  369,  368,  391,  371,  380,
      392,  394,  372,  395,  373,  396,  374,  398,  399,  376,
      379,  400,  381,  401,  402,  404,  382,  405,  386,  407,
      387,  390,  408,  412,  391,  409,  410,  392,  394,  411,

      413,  395,  396,  415,  398,  399,  416,  417,  400,  418,
      401,  402,  419,  404,  405,  421,  429,  407,  431,  435,
      408,  412,  409,  410,  434,  436,  411,  437,  413,  439,
      440,  415,  442,  445,  416,  417,  418,  443,  447,  419,
      444,  448,  421,  429,  449,  444,  431,  435,  451,  452,
      454,  434,  436,  455,  437,  456,  457,  439,  440,  458,
      442,  445,  459,  460,  443,  461,  447,  444,  448,    0,
      465,  449,  444,  466,  469,  451,  452,  470,  454,  471,
      473,  455,  464,  456,  457,  472,  458,  475,  464,  459,
      460,  481,  464,  461,  464,  483,  464,  465,  476,  477,

      466,  469,  479,  480,  485,  470,  484,  471,  473,  486,
      464,  487,  472,  488,  492,  475,  464,  489,  481,  464,
      490,  464,  483,  464,  493,  494,  476,  477,  497,  498,
      479,  480,  485,  484,  499,  500,  486,  501,  487,  502,
      505,  488,  492,  503,  489,  504,  507,  490,  508,  509,
      511,  493,  510,  494,  512,  497,  498,  513,  514,  516,
      517,  499,  500,  519,  521,  501,  522,  502,  505,  523,
      503,  524,  504,  507,  525,  526,  508,  509,  511,  510,
      529,  512,  531,  534,  513,  514,  516,  532,  517,  533,
      519,  535,  521,  522,  536,  541,  523,  542,  524,  543,

        0,  544,  525,  526,  545,    0,  547,  529,  548,    0,
      531,  534,  550,  552,  532,  556,  533,    0,  535,  551,
        0,  536,  553,  541,  557,  542,  561,  543,  544,  562,
      564,  545,  546,  546,  547,  548,  546,  549,  565,  550,
      552,  546,  556,  549,  546,  546,  567,  551,  549,  549,
      553,  568,  557,  569,  561,  570,  571,  562,  564,  572,
      546,  546,  573,  574,  546,  549,  565,  575,  546,  576,
      549,  546,  546,  567,  577,  549,  549,  578,  568,  579,
      569,  580,  570,  581,  571,  582,  584,  572,  583,  585,
      573,  574,  586,  587,  575,  589,  590,  576,  591,  596,

      598,  577,  599,  601,  578,  602,  579,  603,  604,  580,
      581,  605,  606,  582,  584,  583,  585,  607,  608,  586,
      609,  587,  589,  610,  590,  591,  596,  598,  611,  599,
      612,  601,  602,  613,  603,  604,  614,  617,  605,  606,
      615,  616,  618,  619,  607,  620,  608,  609,  621,    0,
      623,  610,  628,  630,  631,  635,  611,  632,  612,  634,
      636,  613,  637,  644,  614,  617,  638,  615,  616,  639,
      618,  619,  620,  640,  642,  645,  621,  623,  646,  628,
      647,  630,  631,  635,  632,  648,  634,  636,  649,  654,
      637,  644,  655,  638,  656,  657,  639,  658,  659,  660,

      640,  642,  661,  645,  662,  646,  663,  647,  664,  665,
        0,  666,  648,  672,  674,  649,  675,  654,  676,  655,
      677,  656,  657,  679,  658,  680,  659,  660,  681,  661,
      682,  684,  662,  685,  663,  687,  664,  665,  666,  688,
      672,  674,  689,  690,  675,  676,  693,  677,  695,  696,
      698,  679,  703,  680,  704,  681,  705,    0,  682,  684,
      685,    0,  687,    0,    0,    0,  688,    0,    0,    0,
      689,  690,    0,    0,  693,  695,    0,  696,  698,  703,
        0,    0,  704,  705,  709,  709,  710,    0,  710,  710,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,

      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708,
      708,  708,  708,  708,  708,  708,  708,  708,  708,  708
    } ;

#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "bsdl_flex.l"
/*
 * $Id$
 *
 * Original Lex source by Ken Parker, 1990
 * Extensions and adaptions for UrJTAG by Arnim Laeuger, 2007
 *
 */
/*----------------------------------------------------------
 *
 *  Lex source for BSDL
 *
 *----------------------------------------------------------*/
/* Date:   901003 */
/*

Email header accompanying the original Yacc code:
  http://www.eda.org/vug_bbs/bsdl.parser

-----------------------------------8<--------------------------------------

Hello All,

This is this first mailing of the BSDL* Version 0.0 parser specifications
we are sending to people who request it from our publicized E-Mail address;

             bsdl%hpmtlx@hplabs.HP.com

You are free to redistribute this at will, but we feel that it would be
better if respondents asked for it directly so that their addresses can
be entered into our list for future mailings and updates.

It would be helpful if you could confirm receipt of this transmission.
We also would be very interested to hear about your experiences with this
information and what you are planning to do with BSDL.

Regards,

Ken Parker
Hewlett-Packard Company


*Boundary-Scan Description Language - as documented in:

"A Language for Describing Boundary-Scan Devices", K.P. Parker
and S. Oresjo, Proceedings 1990 International Test Conference,
Washington DC, pp 222-234


- -----------------cut here---------------------------------------------------


901004.0721                                  Hewlett-Packard Company
901016.1049                                  Manufacturing Test Division
                                             P.O. Box 301
                                             Loveland, Colorado  80537
                                             USA

                                                             October 1990
Hello BSDL Parser Requestor,

   This Electronic Mail reply contains the computer specifications for
Hewlett-Packard's Version 0.0 BSDL parser.  This section of the reply
explains the contents of the rest of this file.

This file is composed of seven (7) parts:

   1) How to use this file

   2) UNIX* Lex source  (lexicographical tokenizing rules)

   3) UNIX* Yacc source (BNF-like syntax description)

   4) A sample main program to recognize BSDL.

   5) A BSDL description of the Texas Instruments 74bct8374 that is
      recognized by the parser, for testing purposes.

   6) The VHDL package STD_1149_1_1990 needed by this parser.

   7) [added 901016] Porting experiences to other systems.


RECOMMENDATION: Save a copy of this file in archival storage before
                processing it via the instructions below.  This will
                allow you to recover from errors, and allow you to
                compare subsequently released data for changes.

DISCLAIMERS:

1.  The IEEE 1149.1 Working Group has not endorsed BSDL Version 0.0 and
    therefore no person may represent it as an IEEE standard or imply that
    a resulting IEEE standard will be identical to it.

2.  The IEEE 1149.1 Working Group recognizes that BSDL Version 0.0 is a
    well-conceived initiative that is likely to excelerate the creation
    of tools that support the 1149.1 standard.  As such, changes and
    enhancements will be carefully considered so as not to needlessly
    disrupt these development efforts.  The overriding goal is the
    ultimate success of the 1149.1 standard.

LEGAL NOTICES:

    Hewlett-Packard Company makes no warranty of any kind with regard to
    this information, including, but not limited to, the implied
    waranties of merchantability and fitness for a particular purpose.

    Hewlett-Packard Company shall not be liable for errors contained
    herein or direct, indirect, special, incidental, or consequential
    damages in connection with the furnishing, performance, or use of
    this material.


*UNIX is a trademark of AT&T in the USA and other countries.

*/
#line 125 "bsdl_flex.l"
/* Begin lex input specifications */

#include <stdlib.h>
#include <ctype.h>

#include "bsdl_sysdep.h"

#include "bsdl_msg.h"

#include "bsdl_bison.h"
#include "bsdl_parser.h"

#ifdef DMALLOC
#include "dmalloc.h"
#endif

#define YY_EXTRA_TYPE urj_bsdl_scan_extra_t *

static char *new_string (urj_bsdl_scan_extra_t *, const char *);

#define BINARY  0
#define DECIMAL 1
#define BIN_X   2
#define HEX     3

/* Fix up warnings from generated lex code */
#define lex_get_column urj_bsdl_get_column
#define lex_set_column urj_bsdl_set_column
#include "lex.h"


#line 1297 "bsdl_flex.c"

#define INITIAL 0
#define RES 1
#define BOU 2
#define REG 3
#define PAC 4
#define ISC 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int urj_bsdl_lex_init (yyscan_t* scanner);

int urj_bsdl_lex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int urj_bsdl_lex_destroy (yyscan_t yyscanner );

int urj_bsdl_get_debug (yyscan_t yyscanner );

void urj_bsdl_set_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE urj_bsdl_get_extra (yyscan_t yyscanner );

void urj_bsdl_set_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *urj_bsdl_get_in (yyscan_t yyscanner );

void urj_bsdl_set_in  (FILE * _in_str ,yyscan_t yyscanner );

FILE *urj_bsdl_get_out (yyscan_t yyscanner );

void urj_bsdl_set_out  (FILE * _out_str ,yyscan_t yyscanner );

yy_size_t urj_bsdl_get_leng (yyscan_t yyscanner );

char *urj_bsdl_get_text (yyscan_t yyscanner );

int urj_bsdl_get_lineno (yyscan_t yyscanner );

void urj_bsdl_set_lineno (int _line_number ,yyscan_t yyscanner );

int urj_bsdl_get_column  (yyscan_t yyscanner );

void urj_bsdl_set_column (int _column_no ,yyscan_t yyscanner );

YYSTYPE * urj_bsdl_get_lval (yyscan_t yyscanner );

void urj_bsdl_set_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int urj_bsdl_wrap (yyscan_t yyscanner );
#else
extern int urj_bsdl_wrap (yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int urj_bsdl_lex \
               (YYSTYPE * yylval_param ,yyscan_t yyscanner);

#define YY_DECL int urj_bsdl_lex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)urj_bsdl_alloc(YY_STATE_BUF_SIZE  ,yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl_lex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			urj_bsdl_ensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				urj_bsdl__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		urj_bsdl__load_buffer_state(yyscanner );
		}

	{
#line 279 "bsdl_flex.l"

#line 1596 "bsdl_flex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 709 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1591 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
					{
					yyg->yy_full_match = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 280 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( CONSTANT ); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 281 "bsdl_flex.l"
{return( PIN_MAP ); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 282 "bsdl_flex.l"
{return( PHYSICAL_PIN_MAP ); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 283 "bsdl_flex.l"
{return( PIN_MAP_STRING ); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 284 "bsdl_flex.l"
{return( TAP_SCAN_IN ); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 285 "bsdl_flex.l"
{return( TAP_SCAN_OUT ); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 286 "bsdl_flex.l"
{return( TAP_SCAN_CLOCK ); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 287 "bsdl_flex.l"
{return( TAP_SCAN_MODE ); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 288 "bsdl_flex.l"
{return( TAP_SCAN_RESET ); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 289 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( INSTRUCTION_LENGTH ); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 290 "bsdl_flex.l"
{yyextra->Base = BINARY;  /* Enable Binary Patterns */
                         return( INSTRUCTION_OPCODE ); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 292 "bsdl_flex.l"
{yyextra->Base = BIN_X;  /* Enable Bin_X Patterns */
                         return( INSTRUCTION_CAPTURE ); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 294 "bsdl_flex.l"
{return( INSTRUCTION_DISABLE ); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 295 "bsdl_flex.l"
{return( INSTRUCTION_GUARD ); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 296 "bsdl_flex.l"
{return( INSTRUCTION_PRIVATE ); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 297 "bsdl_flex.l"
{BEGIN(REG); yyextra->Base = DECIMAL;
                         return( REGISTER_ACCESS ); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 299 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( BOUNDARY_LENGTH ); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 300 "bsdl_flex.l"
{BEGIN(BOU); yyextra->Base = DECIMAL;
                         return( BOUNDARY_REGISTER ); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 302 "bsdl_flex.l"
{yyextra->Base = BIN_X; return( IDCODE_REGISTER ); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 303 "bsdl_flex.l"
{yyextra->Base = BIN_X; return( USERCODE_REGISTER ); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 304 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( COMPLIANCE_PATTERNS ); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 305 "bsdl_flex.l"
{return( COMPONENT_CONFORMANCE ); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 306 "bsdl_flex.l"
{return( STD_1149_1_1990 ); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 307 "bsdl_flex.l"
{return( STD_1149_1_1993 ); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 308 "bsdl_flex.l"
{return( STD_1149_1_2001 ); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 309 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_CONFORMANCE ); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 310 "bsdl_flex.l"
{return( STD_1532_2001 ); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 311 "bsdl_flex.l"
{return( STD_1532_2002 ); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 312 "bsdl_flex.l"
{BEGIN(ISC); yyextra->Base = DECIMAL; return( ISC_PIN_BEHAVIOR ); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 313 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_FIXED_SYSTEM_PINS ); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 314 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_STATUS ); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 315 "bsdl_flex.l"
{return( IMPLEMENTED ); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 316 "bsdl_flex.l"
{yyextra->Base = BIN_X; return( ISC_BLANK_USERCODE ); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 317 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_SECURITY ); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 318 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_DISABLE_READ ); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 319 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_DISABLE_PROGRAM ); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 320 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_DISABLE_ERASE ); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 321 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_DISABLE_KEY ); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 322 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_FLOW ); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 323 "bsdl_flex.l"
{return( UNPROCESSED ); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 324 "bsdl_flex.l"
{return( EXIT_ON_ERROR ); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 325 "bsdl_flex.l"
{return( ARRAY ); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 326 "bsdl_flex.l"
{return( SECURITY ); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 327 "bsdl_flex.l"
{return( PRELOAD ); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 328 "bsdl_flex.l"
{return( INITIALIZE ); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 329 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( REPEAT ); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 330 "bsdl_flex.l"
{return( TERMINATE ); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 331 "bsdl_flex.l"
{return( LOOP ); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 332 "bsdl_flex.l"
{return( WAIT ); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 333 "bsdl_flex.l"
{return( MIN ); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 334 "bsdl_flex.l"
{return( MAX ); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 335 "bsdl_flex.l"
{return( CRC ); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 336 "bsdl_flex.l"
{return( OST ); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 337 "bsdl_flex.l"
{return( DOLLAR ); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 338 "bsdl_flex.l"
{return( EQUAL ); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 339 "bsdl_flex.l"
{return( PLUS ); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 340 "bsdl_flex.l"
{return( MINUS ); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 341 "bsdl_flex.l"
{return( SH_RIGHT ); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 342 "bsdl_flex.l"
{return( SH_LEFT ); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 343 "bsdl_flex.l"
{return( TILDE ); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 344 "bsdl_flex.l"
{return( QUESTION_EXCLAMATION ); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 345 "bsdl_flex.l"
{return( QUESTION_MARK ); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 346 "bsdl_flex.l"
{return( EXCLAMATION_MARK ); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 347 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_PROCEDURE ); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 348 "bsdl_flex.l"
{yyextra->Base = DECIMAL; return( ISC_ACTION ); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 349 "bsdl_flex.l"
{return( PROPRIETARY ); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 350 "bsdl_flex.l"
{return( OPTIONAL ); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 351 "bsdl_flex.l"
{return( RECOMMENDED ); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 352 "bsdl_flex.l"
{return( ISC_ILLEGAL_EXIT ); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 353 "bsdl_flex.l"
{return( BYPASS ); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 354 "bsdl_flex.l"
{return( BOUNDARY ); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 355 "bsdl_flex.l"
{return( CLAMP ); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 356 "bsdl_flex.l"
{return( EXTEST ); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 357 "bsdl_flex.l"
{return( HIGHZ ); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 358 "bsdl_flex.l"
{return( IDCODE ); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 359 "bsdl_flex.l"
{return( INTEST ); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 360 "bsdl_flex.l"
{return( PRELOAD ); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 361 "bsdl_flex.l"
{return( RUNBIST ); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 362 "bsdl_flex.l"
{return( SAMPLE ); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 363 "bsdl_flex.l"
{return( USERCODE ); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 364 "bsdl_flex.l"
{return( DEVICE_ID ); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 365 "bsdl_flex.l"
{return( INPUT ); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 366 "bsdl_flex.l"
{return( OUTPUT2 ); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 367 "bsdl_flex.l"
{return( OUTPUT3 ); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 368 "bsdl_flex.l"
{return( CONTROLR ); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 369 "bsdl_flex.l"
{return( CONTROL ); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 370 "bsdl_flex.l"
{return( INTERNAL ); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 371 "bsdl_flex.l"
{return( CLOCK ); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 372 "bsdl_flex.l"
{return( OBSERVE_ONLY ); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 373 "bsdl_flex.l"
{return( BIDIR ); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 374 "bsdl_flex.l"
{return( BIDIR_IN ); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 375 "bsdl_flex.l"
{return( BIDIR_OUT ); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 376 "bsdl_flex.l"
{return( Z ); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 377 "bsdl_flex.l"
{return( WEAK0 ); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 378 "bsdl_flex.l"
{return( WEAK1 ); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 379 "bsdl_flex.l"
{return( PULL0 ); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 380 "bsdl_flex.l"
{return( PULL1 ); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 381 "bsdl_flex.l"
{return( KEEPER ); }
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 382 "bsdl_flex.l"
{yylineno++; /* Count lines */}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 383 "bsdl_flex.l"
{return( COMMA ); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 384 "bsdl_flex.l"
{return( LPAREN );}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 385 "bsdl_flex.l"
{return( RPAREN );}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 386 "bsdl_flex.l"
{return( LBRACKET ); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 387 "bsdl_flex.l"
{return( RBRACKET ); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 388 "bsdl_flex.l"
{return( COLON );  }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 389 "bsdl_flex.l"
{return( ASTERISK );  }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 390 "bsdl_flex.l"
{ /* Do Nothing on White Space */ }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 391 "bsdl_flex.l"
{ /* Do Nothing on Comments    */ }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 392 "bsdl_flex.l"
{if (yyextra->Base != BIN_X) REJECT;
                         yylval->str = new_string( yyextra, yytext );
                         return( BIN_X_PATTERN );}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 395 "bsdl_flex.l"
{if (yyextra->Base != HEX) REJECT;
                         yylval->str = new_string( yyextra, yytext );
                         return( HEX_STRING );}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 398 "bsdl_flex.l"
{yylval->str = new_string( yyextra, yytext );
                         return( IDENTIFIER ); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 400 "bsdl_flex.l"
{if (yyextra->Base != BINARY) REJECT;
                         yylval->str = new_string( yyextra, yytext );
                         return( BINARY_PATTERN );}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 403 "bsdl_flex.l"
{if (yyextra->Base != DECIMAL) REJECT;
                         yylval->integer = atoi( (char *)yytext );
                         return( DECIMAL_NUMBER );}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 406 "bsdl_flex.l"
{yylval->str = new_string( yyextra, yytext );
                         return( REAL_NUMBER );}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 408 "bsdl_flex.l"
{urj_bsdl_err_set( yyextra->proc_mode, URJ_ERROR_BSDL_BSDL,
                                           "Illegal character %c (/%03o) at line %d:",
                                           (char)yytext[yyleng-1], (int)yytext[yyleng-1],
                                           yylineno );
                         yyextra->Compile_Errors++;
                         return( ILLEGAL );  /* Will cause syntax error */}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(RES):
case YY_STATE_EOF(BOU):
case YY_STATE_EOF(REG):
case YY_STATE_EOF(PAC):
case YY_STATE_EOF(ISC):
#line 414 "bsdl_flex.l"
{
  urj_bsdl_pop_buffer_state(yyscanner );
  if ( !YY_CURRENT_BUFFER )
    yyterminate();
}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 420 "bsdl_flex.l"
ECHO;
	YY_BREAK
#line 2269 "bsdl_flex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * urj_bsdl_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( urj_bsdl_wrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of urj_bsdl_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	yy_size_t number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			urj_bsdl_restart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) urj_bsdl_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 709 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 709 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 708);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		yy_size_t number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					urj_bsdl_restart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( urj_bsdl_wrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void urj_bsdl_restart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        urj_bsdl_ensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            urj_bsdl__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	urj_bsdl__init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	urj_bsdl__load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void urj_bsdl__switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		urj_bsdl_pop_buffer_state();
	 *		urj_bsdl_push_buffer_state(new_buffer);
     */
	urj_bsdl_ensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	urj_bsdl__load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (urj_bsdl_wrap()) processing, but the only time this flag
	 * is looked at is after urj_bsdl_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void urj_bsdl__load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE urj_bsdl__create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) urj_bsdl_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl__create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) urj_bsdl_alloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl__create_buffer()" );

	b->yy_is_our_buffer = 1;

	urj_bsdl__init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with urj_bsdl__create_buffer()
 * @param yyscanner The scanner object.
 */
    void urj_bsdl__delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		urj_bsdl_free((void *) b->yy_ch_buf ,yyscanner );

	urj_bsdl_free((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a urj_bsdl_restart() or at EOF.
 */
    static void urj_bsdl__init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	urj_bsdl__flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then urj_bsdl__init_buffer was _probably_
     * called from urj_bsdl_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void urj_bsdl__flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		urj_bsdl__load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void urj_bsdl_push_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	urj_bsdl_ensure_buffer_stack(yyscanner);

	/* This block is copied from urj_bsdl__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from urj_bsdl__switch_to_buffer. */
	urj_bsdl__load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void urj_bsdl_pop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	urj_bsdl__delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		urj_bsdl__load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void urj_bsdl_ensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)urj_bsdl_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl_ensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)urj_bsdl_realloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE urj_bsdl__scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) urj_bsdl_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	urj_bsdl__switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to urj_bsdl_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       urj_bsdl__scan_bytes() instead.
 */
YY_BUFFER_STATE urj_bsdl__scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return urj_bsdl__scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to urj_bsdl_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE urj_bsdl__scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) urj_bsdl_alloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in urj_bsdl__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = urj_bsdl__scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in urj_bsdl__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE urj_bsdl_get_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int urj_bsdl_get_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int urj_bsdl_get_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *urj_bsdl_get_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *urj_bsdl_get_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t urj_bsdl_get_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *urj_bsdl_get_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void urj_bsdl_set_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void urj_bsdl_set_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "urj_bsdl_set_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void urj_bsdl_set_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "urj_bsdl_set_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see urj_bsdl__switch_to_buffer
 */
void urj_bsdl_set_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void urj_bsdl_set_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int urj_bsdl_get_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void urj_bsdl_set_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * urj_bsdl_get_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void urj_bsdl_set_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* urj_bsdl_lex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int urj_bsdl_lex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) urj_bsdl_alloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* urj_bsdl_lex_init_extra has the same functionality as urj_bsdl_lex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to urj_bsdl_alloc in
 * the yyextra field.
 */

int urj_bsdl_lex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    urj_bsdl_set_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) urj_bsdl_alloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    urj_bsdl_set_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from urj_bsdl_lex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * urj_bsdl_lex_init()
     */
    return 0;
}

/* urj_bsdl_lex_destroy is for both reentrant and non-reentrant scanners. */
int urj_bsdl_lex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		urj_bsdl__delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		urj_bsdl_pop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	urj_bsdl_free(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        urj_bsdl_free(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    urj_bsdl_free ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * urj_bsdl_lex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    urj_bsdl_free ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *urj_bsdl_alloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return (void *) malloc( size );
}

void *urj_bsdl_realloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void urj_bsdl_free (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see urj_bsdl_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 420 "bsdl_flex.l"



/*****************************************************************************
 * void *urj_bsdl_flex_init( int proc_mode )
 *
 * Initializes the scanner and storage elements extra data structure.
 *
 * Parameters
 *   proc_mode : processing mode, consisting of BSDL_MODE_* bits
 *
 * Returns
 *   pointer to newly initialized scanner structure
 ****************************************************************************/
void *
urj_bsdl_flex_init (int proc_mode)
{
    urj_bsdl_scan_extra_t *extra;
    yyscan_t scanner;

    /* get our scanner structure */
    if (urj_bsdl_lex_init (&scanner) != 0)
    {
        urj_bsdl_ftl_set (proc_mode, URJ_ERROR_BSDL_BSDL,
                          "Scanner could not be initialized");
        return NULL;
    }

    if (!(extra = malloc (sizeof (urj_bsdl_scan_extra_t))))
    {
        urj_bsdl_ftl_set (proc_mode, URJ_ERROR_OUT_OF_MEMORY,
                          "No memory");
        urj_bsdl_lex_destroy (scanner);
        return NULL;
    }

    extra->proc_mode = proc_mode;
    extra->Compile_Errors = 0;
    extra->Base = DECIMAL;

    urj_bsdl_set_extra (extra, scanner);

    return scanner;
}


/*****************************************************************************
 * void urj_bsdl_flex_deinit( void *scanner )
 *
 * Deinitializes the scanner and closes the input file.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   void
 ****************************************************************************/
void
urj_bsdl_flex_deinit (void *scanner)
{
    if (urj_bsdl_get_in (scanner))
    {
        /* file might still be open so close it in any case
           e.g. when a compile error occured and the parser didn't hit EOF/urj_bsdl_wrap() */
        fclose (urj_bsdl_get_in (scanner));
        urj_bsdl_set_in (NULL, scanner);
    }
    free (urj_bsdl_get_extra (scanner));
    urj_bsdl_lex_destroy (scanner);
}


/*****************************************************************************
 * void urj_bsdl_wrap(yyscan_t scanner )
 *
 * Closes the input file upon EOF condition.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   1
 ****************************************************************************/
int
urj_bsdl_wrap (yyscan_t scanner)
{
    if (urj_bsdl_get_in (scanner))
    {
        fclose (urj_bsdl_get_in (scanner));
        urj_bsdl_set_in (NULL, scanner);
    }
    return 1;
}


/*****************************************************************************
 * char *new_string( urj_bsdl_scan_extra_t *extra, const char *str )
 *
 * Allocates memory for a string and copies the contents of *str.
 *
 * Parameters
 *   extra : pointer to extra data structure
 *   str   : pointer to string to be duplicated
 *
 * Returns
 *   pointer to allocated and initialized string memory
 ****************************************************************************/
static char *
new_string (urj_bsdl_scan_extra_t *extra, const char *str)
{
    char *n_str;
    size_t n_str_size;

    n_str_size = strlen (str) + 1;
    if ((n_str = malloc (n_str_size)))
    {
        strncpy (n_str, str, n_str_size - 1);
        n_str[n_str_size - 1] = '\0';   /* set very last element to EOS */
    }
    else
        urj_bsdl_ftl_set (extra->proc_mode, URJ_ERROR_OUT_OF_MEMORY,
                          "No memory");

    return (n_str);
}


/*****************************************************************************
 * void urj_bsdl_flex_switch_buffer( yyscan_t scanner, const char *buffer, int lineno )
 *
 * Selects the specified string buffer for further scanning.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *   buffer  : pointer to string buffer to be scanned
 *   lineno  : initial line number offset
 *
 * Returns
 *   void
 ****************************************************************************/
void
urj_bsdl_flex_switch_buffer (yyscan_t scanner, const char *buffer, int lineno)
{
    /* ugly, ulgy, ugly
       prepare yyg for later use of YY_CURRENT_BUFFER */
    struct yyguts_t *yyg = (struct yyguts_t *) scanner;

    /* urj_bsdl__scan_string() switches to the string buffer internally,
       so we must save the current buffer state explicitly by pushing the stack
       and setting top of stack to the current buffer state again.
       urj_bsdl__scan_string() can then savely switch YY_CURRENT_BUFFER to the string buffer.
       urj_bsdl_pop_buffer_state() will delete the string buffer afterwards and pop the saved
       current buffer state. */
    urj_bsdl_push_buffer_state (YY_CURRENT_BUFFER, scanner);
    urj_bsdl__scan_string (buffer, scanner);
    urj_bsdl_set_lineno (lineno, scanner);
}


/*****************************************************************************
 * void urj_bsdl_flex_stop_buffer( yyscan_t scanner )
 *
 * Removes the current buffer from the scanner stack.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   void
 ****************************************************************************/
void
urj_bsdl_flex_stop_buffer (yyscan_t scanner)
{
    urj_bsdl_pop_buffer_state (scanner);
//  if ( !YY_CURRENT_BUFFER )
//    yyterminate();
}


/*****************************************************************************
 * int urj_bsdl_flex_get_compile_errors( yyscan_t scanner )
 *
 * Retrieves the accumulated number of compile errors encountered so far.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   number of compile errors
 ****************************************************************************/
int
urj_bsdl_flex_get_compile_errors (yyscan_t scanner)
{
    urj_bsdl_scan_extra_t *extra = urj_bsdl_get_extra (scanner);
    return extra->Compile_Errors;
}


/*****************************************************************************
 * void urj_bsdl_flex_set_compile_errors( int n, yyscan_t scanner )
 *
 * Sets the number of compile errors to n.
 *
 * Parameters
 *   n       : preset number
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   void
 ****************************************************************************/
static void
urj_bsdl_flex_set_compile_errors (int n, yyscan_t scanner)
{
    urj_bsdl_scan_extra_t *extra = urj_bsdl_get_extra (scanner);
    extra->Compile_Errors = n;
}


/*****************************************************************************
 * int urj_bsdl_flex_postinc_compile_errors( yyscan_t scanner )
 *
 * Increments the number of compile errors.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   number of compile errors before increment
 ****************************************************************************/
int
urj_bsdl_flex_postinc_compile_errors (yyscan_t scanner)
{
    int errors = urj_bsdl_flex_get_compile_errors (scanner);

    urj_bsdl_flex_set_compile_errors (errors + 1, scanner);
    return errors;
}


/*****************************************************************************
 * void urj_bsdl_flex_set_bin_x( yyscan_t scanner )
 *
 * Selects BIN_X mode for pattern matching.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   void
 ****************************************************************************/
void
urj_bsdl_flex_set_bin_x (yyscan_t scanner)
{
    urj_bsdl_scan_extra_t *extra = urj_bsdl_get_extra (scanner);
    extra->Base = BIN_X;
}


/*****************************************************************************
 * void urj_bsdl_flex_set_hex( yyscan_t scanner )
 *
 * Selects HEX mode for pattern matching.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   void
 ****************************************************************************/
void
urj_bsdl_flex_set_hex (yyscan_t scanner)
{
    urj_bsdl_scan_extra_t *extra = urj_bsdl_get_extra (scanner);
    extra->Base = HEX;
}


/*****************************************************************************
 * void urj_bsdl_flex_set_decimal( yyscan_t scanner )
 *
 * Selects DECIMAL mode for pattern matching.
 *
 * Parameters
 *   scanner : pointer to scanner definition structure
 *
 * Returns
 *   void
 ****************************************************************************/
void
urj_bsdl_flex_set_decimal (yyscan_t scanner)
{
    urj_bsdl_scan_extra_t *extra = urj_bsdl_get_extra (scanner);
    extra->Base = DECIMAL;
}


/*
 Local Variables:
 mode:C
 c-default-style:java
 indent-tabs-mode:nil
 End:
*/

